# ExtraCurrencyExchange

Currency Exchange plugin with more supported currency

## Installation

### InvenTree Plugin Manager

... todo ...

### Command Line 

To install manually via the command line, run the following command:

```bash
pip install extracurrencyexchange
```

## Configuration

... todo ...

## Usage

... todo ...
